@@ -4,13 +4,18 @@ from decimal import Decimal
 from enum import Enum
 from pathlib import Path
 from typing import Any
+from uuid import UUID
 
 from .datetime_parse import parse_date, parse_datetime, parse_duration, parse_time
-from .exceptions import ConfigError
+from .exceptions import ConfigError, type_display
 
 NoneType = type(None)
 
 
+def display_as_type(v):
+    return type_display(type(v))
+
+
 def not_none_validator(v):
     if v is None:
         raise TypeError('None is not an allow value')
@@ -26,7 +31,7 @@ def str_validator(v) -> str:
         # is there anything else we want to add here? If you think so, create an issue.
         return str(v)
     else:
-        raise ValueError(f'str or byte type expected not {type(v)}')
+        raise TypeError(f'str or byte type expected not {display_as_type(v)}')
 
 
 def bytes_validator(v) -> bytes:
@@ -74,7 +79,10 @@ def ordered_dict_validator(v) -> OrderedDict:
 def dict_validator(v) -> dict:
     if isinstance(v, dict):
         return v
-    return dict(v)
+    try:
+        return dict(v)
+    except TypeError as e:
+        raise TypeError(f'value is not a valid dict, got {display_as_type(v)}') from e
 
 
 def list_validator(v) -> list:
@@ -99,6 +107,17 @@ def enum_validator(v, field, **kwargs) -> Enum:
     return field.type_(v)
 
 
+def uuid_validator(v) -> UUID:
+    if isinstance(v, UUID):
+        return v
+    elif isinstance(v, str):
+        return UUID(v)
+    elif isinstance(v, (bytes, bytearray)):
+        return UUID(v.decode())
+    else:
+        raise ValueError(f'str, byte or native UUID type expected not {type(v)}')
+
+
 # order is important here, for example: bool is a subclass of int so has to come first, datetime before date same
 _VALIDATORS = [
     (Enum, [enum_validator]),
@@ -122,6 +141,7 @@ _VALIDATORS = [
     (list, [list_validator]),
     (tuple, [tuple_validator]),
     (set, [set_validator]),
+    (UUID, [not_none_validator, uuid_validator]),
 ]
 
 
@@ -133,5 +153,5 @@ def find_validators(type_):
             if issubclass(type_, val_type):
                 return validators
         except TypeError as e:
-            raise TypeError(f'error checking inheritance of {type_!r} (type: {type(type_)})') from e
+            raise TypeError(f'error checking inheritance of {type_!r} (type: {display_as_type(type_)})') from e
     raise ConfigError(f'no validator found for {type_}')
